#!/usr/bin/perl -w 
###############################################################################
#   afick_planning.pl
#      it's a part of the afick project
#
#    Copyright (C) 2002-2004 by Eric Gerbier
#    Bug reports to: gerbier@users.sourceforge.net
#    $Id: afick_planning.pl,v 1.2 2005/04/20 07:33:46 gerbier Exp $
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
###############################################################################
# batch job for afick software on windows
# the problem is to alert the user if something change
# on unix, cron send mails, but on windows, it could be difficult to find a smtp server
# so we will use MessageBox
###############################################################################

use strict;
use Win32;    # for MsgBox

my $afick    = 'afick.pl';                    # afick's program name
my $conffile = $ARGV[0] || 'windows.conf';    # afick's config file

###############################################################################
# open a messagebox
sub message_box($) {
	my $message = shift(@_);

	Win32::MsgBox( $message, 0, "Afick's warning" );
}
###############################################################################
# send a message and exit
sub send_warning($) {
	my $message = shift(@_);

	message_box($message);
	die "$message";
}
###############################################################################
# for debugging
sub send_debug($) {
	my $message = shift(@_);

	message_box($message);
}
###############################################################################
# read config file and populate an hash-table
sub read_macros($) {
	my $file = shift(@_);

	my %mac;

	open( CONF, '<', $file )
	  or send_warning("can not open afick's config file $file : $!");
	while ( my $ligne = <CONF> ) {
		chomp($ligne);
		if ( $ligne =~ m/\@\@define (\w+) (.*)/ ) {
			$mac{$1} = $2;
		}
	}
	close(CONF);
	return %mac;
}
###############################################################################
# 				MAIN
###############################################################################

# debug
#send_debug("afick_planning begin");

# check if afick exists
send_warning("afick's executable $afick not found") unless ( -f $afick );

# check if config file exists
send_warning("afick's configuration file $conffile not found")
  unless ( -f $conffile );

my %macros = read_macros($conffile);

# set default if necessary
$macros{BATCH}   = 1 unless ( exists( $macros{BATCH} ) );
$macros{VERBOSE} = 0 unless ( exists( $macros{VERBOSE} ) );
$macros{REPORT}  = 1 unless ( exists( $macros{REPORT} ) );

exit unless ( $macros{BATCH} );

# notes : LINES, NICE and MAILTO are not used

# launch afick
#send_debug("launch afick");
my @output = `perl -w $afick -c $conffile --update`;

#send_debug("afick end");
return unless ( $macros{REPORT} );

# remove comments and blank lines
my @changes = grep( !/^$/, grep( !/^#/, @output ) );

# get summary
my @summary = grep ( /files scanned/, @output );

# test result
if ( scalar(@changes) ) {
	send_warning("WARNING : afick detects changes : @summary ");
}
elsif ( $macros{VERBOSE} ) {
	send_warning("INFO : afick's run is clean : @summary");
}
