#!/usr/bin/perl -w
###############################################################################
##    Copyright (C) 2002 by Eric Gerbier
##    Bug reports to: gerbier@users.sourceforge.net
##    $Id: planning.pl,v 1.6 2004/12/15 10:01:11 gerbier Exp $
##
##    This program is free software; you can redistribute it and/or modify
##    it under the terms of the GNU General Public License as published by
##    the Free Software Foundation; either version 2 of the License, or
##    (at your option) any later version.
##
##    This program is distributed in the hope that it will be useful,
##    but WITHOUT ANY WARRANTY; without even the implied warranty of
##    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##    GNU General Public License for more details.
##
################################################################################
# test for service planning (windows
# and add a task to windows service planning
# ask for days, hour, time
################################################################################
use strict;
use diagnostics;
use Win32::OLE::NLS qw(:LOCALE :DEFAULT );    # to get days of week
use Tk;

# initialize optionmenu with defaults
my $v_hour = 12;    # hour to launch service planning
my $v_min  = 0;     # minutes of hour to launch service planning

my $w_set;          # widget to quit (change state)
my $w_days;         # widget list of days of week
my $main;           # main widget

my $config_file = $ARGV[0] || "windows.conf";

################################################################################
# set service planning with our choices (days, hour, min)
sub set_planning() {

	# get list of days
	my @tab_sel = $w_days->curselection();
	my @t_days;
	foreach my $sel (@tab_sel) {
		push @t_days, $w_days->get($sel);
	}

	# add it :
	my $cmd =
	    'at ' . $v_hour . ':' . $v_min
	  . ' /interactive /every:'
	  . join( ',', @t_days )
	  . ' "C:\Program Files\afick\afick_scan.cmd" '
	  . $config_file;

	#print "cmd=$cmd\n";
	system("$cmd");

	# at answer is localized, so difficult to parse
	# I prefer to ask planning
	my $find = scalar( test_planning() );
	if ( $find == 1 ) {

		# ok : exit
		$main->Label( -text => 'afick is added to service planning' )->pack();
		$main->update();
		sleep(2);
		$main->destroy();
	}
	else {

		# display an error message
		$w_set->configure( -state => 'disabled' );
		$main->Label( -text =>
'problem to add afick on service planning : you have to set by hand'
		)->pack();
		$main->Button( -text => 'quit', -command => [ $main => 'destroy' ] )
		  ->pack();
	}
}
################################################################################
# build the interface to set day, hour, min
sub display_time($) {
	my $top = shift(@_);

	my $frame = $top->Frame()->pack();
	$w_set =
	  $top->Button( -text => 'set planning', -command => \&set_planning )
	  ->pack( -side => 'left' );
	$top->Button( -text => 'quit', -command => [ $main => 'destroy' ] )
	  ->pack( -side => 'left' );

	# hours
	$frame->Label( -text => 'hour' )->pack( -side => 'left' );
	my @hour = ( 0 .. 23 );
	$frame->Optionmenu(
		-options      => [@hour],
		-textvariable => \$v_hour,
	)->pack( -side => 'left' );

	# minutes
	$frame->Label( -text => 'minutes' )->pack( -side => 'left' );
	my @min = ( 0 .. 59 );
	$frame->Optionmenu(
		-options      => [@min],
		-textvariable => \$v_min,
	)->pack( -side => 'left' );

	# day of week too
	my @week;

	# get localisation from windows
	for ( 1 .. 7 ) {
		push @week,
		  GetLocaleInfo( LOCALE_SYSTEM_DEFAULT, eval "LOCALE_SDAYNAME$_ " );
	}
	$frame->Label( -text => 'days' )->pack( -side => 'left' );
	$w_days =
	  $frame->Listbox( -selectmode => 'multiple' )->pack( -side => 'left' );
	$w_days->insert( 'end', @week );

	# choice a day will allow submit
	$w_days->bind( '<Button-1>',
		sub { $w_set->configure( -state => 'normal' ) } );

	# lock submit
	$w_set->configure( -state => 'disabled' );
}
################################################################################
# ask service planning for afick tasks
# return match lines
sub test_planning() {
	my @tab = `at`;

	# is afick already registered ?
	my $find = 0;
	my @lignes;
	foreach my $elem (@tab) {

		#print "at return : $elem\n";
		chomp($elem);
		if ( $elem =~ m/afick/ ) {
			push @lignes, $elem;
		}
	}
	return @lignes;
}
################################################################################
#			main
################################################################################

$main = MainWindow->new( -title => 'afick-planning' );

# is afick already registered ?
my @find = test_planning();
my $find = scalar(@find);
if ( $find == 1 ) {

	# only one task found
	# display found line
	$main->Label( -text => "find : @find" )->pack();
	$main->Button( -text => 'quit', -command => [ $main => 'destroy' ] )
	  ->pack();
}
elsif ( $find > 1 ) {

	# several task found : looks strange
	$main->Label( -text =>
"found several afick tasks : $find; have a clean-up and rerun planning.pl"
	)->pack();
	$main->Button( -text => 'quit', -command => [ $main => 'destroy' ] )
	  ->pack();
}
else {

	# no afick found : we can set it
	$main->Label( -text => 'add afick task in service planning at :' )->pack();

	# choose time to launch
	display_time($main);
}

MainLoop;
